@@ -9,17 +9,17 @@ class stylize_Test(unittest.TestCase):
     # Actions
 
     def setUp(self):
-        self.stylize = partial(component.stylize, 'test')
+        self.pstylize = partial(component.stylize, 'test')
 
     # Tests
 
     def test_1(self):
-        result = self.stylize(bold=True)
+        result = self.pstylize(bold=True)
         self.assertEqual(result, '\x1b[1mtest\x1b[0m')
 
     def test_2(self):
-        result = self.stylize(foreground='red')
+        result = self.pstylize(foreground='red')
         self.assertEqual(result, '\x1b[31mtest\x1b[0m')
 
     def test_with_error(self):
-        self.assertRaises(ValueError, self.stylize, error='error')
+        self.assertRaises(ValueError, self.pstylize, error='error')
